@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.64 2003/12/23 14:21:12 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.65 2004/01/07 15:43:15 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -790,9 +790,9 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     do_immed
 },       
 {        
-    N_("y<sup><i>x</i></sup>"),
-    N_("y to the power of displayed value"),
-    N_("Y to the x"),
+    N_("x<sup><i>y</i></sup>"),
+    N_("Raise displayed value to the power of y"),
+    N_("X to the y"),
     { 0, 0 },   
     { GDK_y, 0 },
     'y',
