@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.36 2003/12/23 14:21:12 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.39 2004/01/06 22:01:25 richb Exp $
  *
- *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -83,13 +83,8 @@ remove_tsep(char *str) {
     char *dstp = str;
     size_t tsep_len;
 
-/* If there are no thousands separators in the numeric string, just return
- * without doing anything. This is needed because the initial constant
- * definitions are potentially in read-only memory, and shouldn't be adjusted.
- */
-
-    if (strstr(str, v->tsep) != NULL) {
-        tsep_len = strlen(v->tsep);
+    tsep_len = strlen(v->tsep);
+    if (tsep_len && strstr(str, v->tsep) != NULL) {
         while (*srcp != '\0') {
             if (memcmp(srcp, v->tsep, tsep_len) == 0) {
                 srcp += tsep_len;
@@ -133,6 +128,7 @@ clear_display(int initialise)
         v->show_paren = 0;
         v->opsptr     = 0;            /* Clear parentheses stacks. */
         v->numsptr    = 0;
+        v->noparens   = 0;
         set_hyp_item(FALSE);          /* Also clears v->hyperbolic. */
         set_inv_item(FALSE);          /* Also clears v->inverse. */
     }
@@ -169,6 +165,7 @@ initialise()
     v->error         = 0;           /* Currently no display error. */
     v->cur_op        = '?';         /* No arithmetic operator defined yet. */
     v->old_cal_value = '?';
+    v->pending       = 0;
     i = 0;
     mpcim(&i, v->MPresult);         /* No previous result yet. */
     mpcim(&i, v->MPlast_input);
@@ -484,7 +481,10 @@ paren_disp(char c)
         if (!n) {
             return;
         }
-        if (v->display[n-1] == '(') {
+
+        if (v->display[n-1] == ')') {
+            v->noparens++;
+        } else if (v->display[n-1] == '(') {
             v->noparens--;
             if (!v->noparens) {
                 v->pending = v->opsptr = v->numsptr = 0;
